dataMovies.errors.error API documentation

# Module `dataMovies.errors.error`

Expand source code

    #!/usr/bin/env python3

    class Error(Exception):
        """Main parent error class
        """
        def __init__(self, message):
            """Constructor
            Args:
                message: the error message as a string
            """
            self.message = message
            super().__init__(self.message)

## Classes

`class Error (message)`

  Main parent error class

  Constructor

  ## Args

  `message`
    the error message as a string
  Expand source code

      class Error(Exception):
          """Main parent error class
          """
          def __init__(self, message):
              """Constructor
              Args:
                  message: the error message as a string
              """
              self.message = message
              super().__init__(self.message)

  ### Ancestors

  - builtins.Exception
  - builtins.BaseException

  ### Subclasses

  - ImdbResponseContentError
  - ImdbResponseStatusCodeError